import React from 'react'
import { useDrag, useDrop } from 'react-dnd'
import { Popover } from 'antd'
import { EditOutlined, CloseOutlined } from '@ant-design/icons'

import MkIcon from '@/components/mk-icon'
import './index.scss'

const Card = ({ id, card, moveCard, findCard, doubleClickCard, editCard, delCard }) => {
  const originalIndex = findCard(id).index
  const [{ isDragging }, drag] = useDrag({
    item: { type: 'tabs', id, originalIndex },
    collect: monitor => ({
      isDragging: monitor.isDragging(),
    }),
  })
  const [, drop] = useDrop({
    accept: 'tabs',
    canDrop: () => true,
    drop: (item) => {
      const { id: draggedId, originalIndex } = item
      
      if (originalIndex === undefined) {
        item.dropTargetId = id
      } else if (draggedId && draggedId !== id) {
        const { index: overIndex } = findCard(id)
        moveCard(draggedId, overIndex)
      }
    }
  })

  const doubleClick = () => {
    doubleClickCard(id)
  }

  const edit = () => {
    editCard(id)
  }

  const del = () => {
    delCard(id)
  }

  const opacity = isDragging ? 0.5 : 1

  return (
    <Popover overlayClassName="mk-popover-control-wrap" mouseLeaveDelay={0.2} mouseEnterDelay={0.2} content={
      <div className="mk-popover-control">
        <EditOutlined className="edit" onClick={edit} />
        <CloseOutlined className="close" onClick={del} />
      </div>
    } trigger="hover">
      <div className="page-card" style={{ opacity: opacity}}>
        <div ref={node => drag(drop(node))} onDoubleClick={doubleClick}>
          {card.icon ? <MkIcon type={card.icon} /> : null}
          {card.label}
        </div>
      </div>
    </Popover>
  )
}
export default Card
